COMMENT
*********************************************************************************
Procedure: Case1_Payments_DIV
Purpose:   Performs data prep and integrity verification on the Payments_DIV table
Results:   Three tables: All exceptions; exceptions by Product and
           exceptions by Vendor
Created:   February 2020 by Arbutus Trainer
Modified:  June 2020 by Arbutus Trainer
Version:   1.2
*********************************************************************************
END

COMMENT **Set the environment

SET DEFAULT
SET SAFETY OFF
SET TEMP "Temp_"
CLOSE PRIMARY SECONDARY

COMMENT **Analysis

COMMENT **Test 1
OPEN Payments_DIV
VERIFY FIELDS ALL ERRORLIMIT 20 TO SCREEN
CLOSE PRIMARY SECONDARY
IF WRITE1 = 20 PAUSE "There are at least 20 validity errors. Please check the Command Log, investigate and resolve the issues before continuing."
IF WRITE1 = 20 RETURN ALL
IF WRITE1 < 20 DO .DIV_Tests


PROCEDURE DIV_Tests

COMMENT **Test 1 Continued
OPEN Payments_DIV
VERIFY FIELDS ALL ERRORLIMIT 20 TO "R_Validity_Errors"
EXTRACT RECORD TO Temp_Payments_DIV
OPEN Temp_Payments_DIV
DEFINE FIELD c_RecordNum COMPUTED Recno( )
OPEN r_Validity_Errors
INDEX ON RECNO TO "r_Validity_Errors_on_RECNO"
OPEN Temp_Payments_DIV
DEFINE RELATION c_RecordNum WITH r_Validity_Errors INDEX r_Validity_Errors_on_RECNO
DEFINE FIELD T1_Validity COMPUTED
 AS "T1_Validity"
1 IF r_Validity_Errors.RECNO <> 0
0

COMMENT **Test 2
DEFINE FIELD T2_Non_Conforming_InvoiceNo COMPUTED
AS "T2_Non-Conforming;Invoice No"
1 IF NOT (BETWEEN( Length( Alltrim( Invoice_Number)), 6, 7) AND Match( Format( Invoice_Number) "999999" "9999999"))
0
SET FILTER TO T2_Non_Conforming_InvoiceNo = 1
COUNT

COMMENT **Test 3
DEFINE FIELD T3_Non_Conforming_VendorNo COMPUTED
AS "T3_Invalid;Vendor No"
1 IF Length(Alltrim(Vendor_Number)) <> 5 AND Format(Alltrim(Vendor_Number)) <> "99999"
0
SET FILTER TO T3_Non_Conforming_VendorNo = 1
COUNT

COMMENT **Test 4
DEFINE FIELD T4_Blank_Invalid_Trans_Date COMPUTED
AS "T4_Blank Invalid;Trans Date"
1 IF Trans_Date = `19000101`
0
SET FILTER TO T4_Blank_Invalid_Trans_Date = 1
COUNT

COMMENT **Test 5
DEFINE FIELD T5_Trans_Date_Outside_2024 COMPUTED
AS "T5_Trans Date;Outside 2024"
1 IF NOT Between(Trans_Date `20240101` `20241231`) AND Trans_Date <> `19000101`
0
SET FILTER TO T5_Trans_Date_Outside_2024 = 1
COUNT

COMMENT **Test 6
DEFINE FIELD T6_Non_Conforming_ProdNo COMPUTED
AS "T6_Non-Conforming;Product No"
1 IF Format( Prod_No ) <> "XX999" AND Length(Alltrim(Prod_No)) <> 5
0
SET FILTER TO T6_Non_Conforming_ProdNo = 1
COUNT

COMMENT **Test 7
DEFINE FIELD T7_Early_Due_Date COMPUTED
AS "T7_Early;Due Date"
1 IF Due_Date - Trans_Date < 7 AND Verify( Trans_Date ) AND Verify( Due_Date )
0
SET FILTER TO T7_Early_Due_Date = 1
COUNT

COMMENT **Test 8
DEFINE FIELD T8_Amounts_Not_Positive COMPUTED
AS"T8_Amounts;Not Positive"
1 IF Amount <= 0
0
SET FILTER TO T8_Amounts_Not_Positive = 1
COUNT

COMMENT **Score
DEFINE FIELD T9_Score COMPUTED T1_Validity + T2_Non_Conforming_InvoiceNo + T3_Non_Conforming_VendorNo + T4_Blank_Invalid_Trans_Date + T5_Trans_Date_Outside_2024 + T6_Non_Conforming_ProdNo + T7_Early_Due_Date + T8_Amounts_Not_Positive

COMMENT
************** Reporting*****************
END

OPEN Temp_Payments_DIV
EXTRACT RECORD TO R_All_DIV_Exceptions IF T9_Score > 0

OPEN R_All_DIV_Exceptions

COMMENT Create the report grouped by Vendor

CLASSIFY ON Vendor_Number ACCUMULATE T9_Score Amount TO R_DIV_Exceptions_By_Vendor TOP ALL
OPEN R_DIV_Exceptions_By_Vendor

COMMENT Create the report grouped by Product

OPEN R_All_DIV_Exceptions
CLASSIFY ON Prod_No ACCUMULATE T9_Score Amount TO R_DIV_Exceptions_By_Product TOP ALL
OPEN R_DIV_Exceptions_By_Product



COMMENT
************** Cleanup*****************
END

DELETE TEMP OK

