COMMENT
***********************************************************************************
Procedure: Case2_T_and_E
Purpose:   This procedure creates exception files for the 8 objectives
           to solve case study 2 Travel and Entertainment
Results:   Individual tables for the exceptions
           Excel spreadsheet with a worksheet for each result
           Final report showing employees with a larger percentage of exception
           dollars than their share of total expenses
Created:   February 2020 by Arbutus Trainer
Modified:  June 2020 by Arbutus Trainer
Version:   1.2
***********************************************************************************
END

COMMENT **Set the environment

SET DEFAULT
SET SAFETY OFF
SET TEMP "Temp_"
CLOSE PRIMARY ALL

COMMENT **Analysis

COMM Objective 1
OPEN T_and_E_Claims
SET FILTER TO IsBlank( Merchant_Name ) AND Expense_Type <> "Mileage"
EXTRACT ALL TO Test1_Missing_Merchant_Name
OPEN Test1_Missing_Merchant_Name
DEFINE FIELD c_Test COMPUTED "1 Missing Merch Name"
EXPORT FIELDS ALL EXCEL QUALIFIER '""' TO "T&E_Exceptions" TABLE "Test1_Missing_Merchant_Name"

COMM Objective 2
OPEN T_and_E_Claims
SUMMARIZE ON Employee_ID Expense_Date Expense_Type FIELDS Expense_Amount SUMMTYPE SUM AS 'Expense_Amount' IF Match( Expense_Type  "Individual Breakfast" "Individual Lunch" "Individual Dinner" ) PRESORT TO Temp_Meal_Claims
OPEN Temp_Meal_Claims
DEFINE FIELD c_Meal_Limit COMPUTED
AS "Meal;Limit"
25 IF Match( Expense_Type  "Individual Breakfast" "Individual Lunch")
75 IF Expense_Type = "Individual Dinner"
0.00

DEFINE FIELD c_Exceeds_Meal_Limit COMPUTED
AS "c_Exceeds_Meal_Limit"
Expense_Amount - c_Meal_Limit IF Expense_Amount > c_Meal_Limit
0.00

EXTRACT ALL TO Test2_Meals_Exceed_Limit IF c_Exceeds_Meal_Limit > 0
OPEN Test2_Meals_Exceed_Limit
TOTAL c_Exceeds_Meal_Limit
DEFINE FIELD c_Test COMPUTED "2_Exceeds_Meal_Limit"
EXPORT FIELDS ALL EXCEL QUALIFIER '""' TO "T&E_Exceptions" TABLE "Test2_Meals_Exceed_Limit"

COMM Objective 3
OPEN T_and_E_Claims
EXTRACT ALL TO Test3_Misc_Claims_Exceed_100 IF Expense_Type = "Miscellaneous" AND Expense_Amount > 100
OPEN Test3_Misc_Claims_Exceed_100
DEFINE FIELD c_Test COMPUTED "3 Misc Over 100"
EXPORT FIELDS ALL EXCEL QUALIFIER '""' TO "T&E_Exceptions" TABLE "Test3_Misc_Claims_Exceed_100"

COMM Objective 4
OPEN Merchant_Master
INDEX ON MERCHANTID TO "Merchant_Master_on_MERCHANTID"

OPEN T_and_E_Claims
DEFINE RELATION Merchant_ID WITH Merchant_Master INDEX Merchant_Master_on_MERCHANTID

OPEN SIC_Codes_Master
INDEX ON SIC_CODE TO "SIC_Codes_Master_on_SIC_CODE"

OPEN T_and_E_Claims
DEFINE RELATION Merchant_Master.SIC_CODE WITH SIC_Codes_Master INDEX SIC_Codes_Master_on_SIC_CODE
SET FILTER TO SIC_Codes_Master.APPROVED = "N"
EXTRACT FIELDS Employee_ID Expense_Date Expense_Type Expense_Amount Merchant_Name SIC_Codes_Master.APPROVED AS 'APPROVED' TO "Test4_TE_Claims_No_Approval" OPEN
OPEN Test4_TE_Claims_No_Approval
DEFINE FIELD c_Test COMPUTED "4 No Approval"
EXPORT FIELDS ALL EXCEL QUALIFIER '""' TO "T&E_Exceptions" TABLE "Test4_TE_Claims_No_Approval"

COMM Objective 5
OPEN T_and_E_Claims
SUMMARIZE ON Employee_ID Expense_Type Expense_Date FIELDS Expense_Amount SUMMTYPE SUM AS 'Expense_Amount' IF Expense_Type = "Hotel        " PRESORT TO "Temp_Hotel_Claims_Summary"
OPEN Temp_Hotel_Claims_Summary
EXTRACT FIELDS ALL TO Test5_Multiple_Hotel_Claims IF COUNT > 1
OPEN Test5_Multiple_Hotel_Claims
DEFINE FIELD c_Test COMPUTED "5 Multi Hotel Claims"
EXPORT FIELDS ALL EXCEL QUALIFIER '""' TO "T&E_Exceptions" TABLE "Test5_Multiple_Hotel_Claims"

COMM Objective 6
OPEN T_and_E_Claims
EXTRACT FIELDS ALL TO "Temp_Group_Meals_Events" IF Match(Expense_Type, "Business" "Conferences" "Department" "Entertainment" "International""Team") AND NOT Find("Taxi" Expense_Type)
OPEN Temp_Group_Meals_Events
DEFINE FIELD c_Cost_Per_Attendee COMPUTED
AS "Cost Per;Attendee"
Expense_Amount / Number_of_Attendees IF Number_of_Attendees > 0
Expense_Amount

EXTRACT FIELDS ALL TO Test6_Group_Claims_Exceptions IF c_Cost_Per_Attendee > 75
OPEN Test6_Group_Claims_Exceptions
DEFINE FIELD c_Test COMPUTED "6 Group Claim Exceptions"
EXPORT FIELDS ALL EXCEL QUALIFIER '""' TO "T&E_Exceptions" TABLE "Test6_Group_Claims_Exceptions"

COMM Objective 7
OPEN T_and_E_Claims
EXTRACT FIELDS ALL TO "Test7_Stale_Claims" IF Report_Date - Expense_Date > 90
OPEN Test7_Stale_Claims
DEFINE FIELD c_Test COMPUTED "7 Stale Claims"
EXPORT FIELDS ALL EXCEL QUALIFIER '""' TO "T&E_Exceptions" TABLE "Test7_Stale_Claims"

COMM Objective 8
APPEND Test1_Missing_Merchant_Name Test2_Meals_Exceed_Limit Test3_Misc_Claims_Exceed_100 Test4_TE_Claims_No_Approval Test5_Multiple_Hotel_Claims Test6_Group_Claims_Exceptions Test7_Stale_Claims TO Temp_TE_All_Exceptions

CLASSIFY ON Employee_ID ACCUMULATE Expense_Amount TO Temp_Classify_Exceptions_By_Employee

OPEN T_and_E_Claims
CLASSIFY ON Employee_ID ACCUMULATE Expense_Amount TO Temp_Classify_All_Claims

OPEN Temp_Classify_All_Claims
OPEN Temp_Classify_Exceptions_By_Employee SECONDARY
JOIN PKEY Employee_ID FIELDS ALL SKEY Employee_ID WITH ALL TO Temp_All_Claims_Join_Exceptions PRESORT SECSORT

OPEN Temp_All_Claims_Join_Exceptions
EXTRACT ALL TO Test8_Policy_Violations_Exceed_Expense_Share IF FIELD_PERCENTAGE2 > FIELD_PERCENTAGE
OPEN Test8_Policy_Violations_Exceed_Expense_Share
EXPORT FIELDS ALL EXCEL QUALIFIER '""' TO "T&E_Exceptions" TABLE "Test8_Policy_Violations_Exceed_Expense_Share"

COMM Objective 9
OPEN Temp_TE_All_Exceptions
CROSSTAB ON Employee_ID Columns c_Test TO "Exceptions_Summary_by_Employee"

COMM Cleanup
CLOSE PRIMARY SECONDARY
DELETE TEMP OK

