COMMENT
Procedure: Case3_Objective3_and_4
*******************************************************************************************************************
Purpose:   Identifies payments where discounts were not taken. Identifies payments where
           late penalties were incurred but not paid
Results:   Table of discounts not taken and penalties incurred but not paid by vendor
Created:   February 2020 by Arbutus Trainer
Modified:  August 2020 by Arbutus Trainer
Version:   1.3
******************************************************************************************************************
END

COMMENT **Set environment

SET DEFAULT
SET SAFETY OFF
SET TEMP "Temp_"
CLOSE PRIMARY ALL

COMM **Summarize Payments and ILI tables and join them to prepare the tables for analysis
OPEN Payments
SUMMARIZE ON Vendor_Number Invoice_Number FIELDS Net_Payment_Amount SUMMTYPE SUM AS 'SUM_Net_Payment_Amount' Payment_Date SUMMTYPE FIRST AS 'FIRST_Payment_Date' PRESORT TO "R_Payments_Summ_Vendor_Invoice"

OPEN Invoice_Line_Items
SUMMARIZE ON Vendor_Number Invoice_Number FIELDS Amount SUMMTYPE SUM AS 'SUM_Amount' Invoice_Date SUMMTYPE FIRST AS 'FIRST_Invoice_Date' Due_Date SUMMTYPE FIRST AS 'FIRST_Due_Date' PRESORT TO R_ILI_Summ_Vendor_Invoice

OPEN R_ILI_Summ_Vendor_Invoice
OPEN R_Payments_Summ_Vendor_Invoice SECONDARY
JOIN PKEY Vendor_Number Invoice_Number FIELDS ALL SKEY Vendor_Number Invoice_Number WITH ALL TO R_ILI_Summ_Join_Payments_Summ PRIMARY PRESORT SECSORT

OPEN Vendor_Master
INDEX ON Vendor_No TO "Vendor_Master_on_Vendor_No"

OPEN R_ILI_Summ_Join_Payments_Summ
DEFINE RELATION Vendor_Number WITH Vendor_Master INDEX Vendor_Master_on_Vendor_No

OPEN R_ILI_Summ_Join_Payments_Summ

COMM ** Objective 3 Discounts
DEFINE FIELD c_Actual_Discount COMPUTED
AS "Actual;Discount"
SUM_Amount - SUM_Net_Payment_Amount IF Vendor_Master.Terms = "1-10-N30" AND FIRST_Payment_Date <= FIRST_Due_Date
0.00

DEFINE FIELD c_Calculated_Discount COMPUTED
AS "Calculated;Discount"
SUM_Amount * .01 IF Vendor_Master.Terms = "1-10-N30" AND FIRST_Payment_Date <= FIRST_Due_Date
0.00

DEFINE FIELD c_Discounts_Not_Taken COMPUTED c_Calculated_Discount - c_Actual_Discount

TOTAL FIELDS c_Actual_Discount c_Calculated_Discount c_Discounts_Not_Taken

COMMENT ** Objective 4 Penalties

DEFINE FIELD c_Actual_Penalties COMPUTED
AS "Actual;Penalties"
SUM_Net_Payment_Amount - SUM_Amount IF Match(Vendor_Master.Terms "N30" "1-10-N30") AND FIRST_Payment_Date - FIRST_Invoice_Date >30
SUM_Net_Payment_Amount - SUM_Amount IF Vendor_Master.Terms = "N45"  AND FIRST_Payment_Date - FIRST_Invoice_Date > 45
0.00

DEFINE FIELD c_Calculated_Penalties COMPUTED
AS "Calculated;Penalties"
SUM_Amount * .01 IF Match(Vendor_Master.Terms "N30" "1-10-N30") AND FIRST_Payment_Date - FIRST_Invoice_Date > 30
SUM_Amount * .01 IF Vendor_Master.Terms = "N45"  AND FIRST_Payment_Date - FIRST_Invoice_Date > 45
0.00

DEFINE FIELD c_Penalties_Not_Paid COMPUTED c_Calculated_Penalties - c_Actual_Penalties

TOTAL FIELDS c_Actual_Penalties c_Calculated_Penalties c_Penalties_Not_Paid

COMMENT ** Create a report showing totals by Vendor

SUMMARIZE ON Vendor_Number FIELDS c_Discounts_Not_Taken SUMMTYPE SUM AS 'SUM_c_Discounts_Not_Taken' c_Penalties_Not_Paid SUMMTYPE SUM AS 'SUM_c_Penalties_Not_Paid' IF c_Discounts_Not_Taken <> 0 OR c_Penalties_Not_Paid <> 0 TO R_Discount_Penalty_Exceptions_By_Vendor PRESORT

OPEN R_Discount_Penalty_Exceptions_By_Vendor

COMMENT *** Cleanup
DELETE TEMP OK
